@@ -1,4 +1,5 @@
-from beanstalk.tasks.action.server import create_database
+from beanstalk.tasks.action.server import (create_database, install_pip_requirements, compile_python_code,
+                                           create_venv, initialize_git, install_yum_packages)
 
 
 def _(var):
@@ -8,6 +9,7 @@ def _(var):
 # Beanstalk tool behavior
 #-----------------------------------------------------------------------------------------------------------------------
 VERBOSE = 3
+ALLOW_INSTALL_YUM_PACKAGES = True
 
 # Beanstalk Installation
 #-----------------------------------------------------------------------------------------------------------------------
@@ -33,8 +35,24 @@ POST_COMMIT_ACTIONS = []  # project_name
 PRE_RELOAD_ACTIONS = []  # project_name
 POST_RELOAD_ACTIONS = []  # project_name
 
-PRE_INSTALL_ACTIONS = []  # project_name
+PRE_INSTALL_ACTIONS = [
+    install_yum_packages,
+    install_pip_requirements,
+    compile_python_code
+]  # project_name
 POST_INSTALL_ACTIONS = []  # project_name
 
 PRE_COMMIT_ACTION = []  # project_name
 POST_COMMIT_ACTION = []  # project_name
+
+PRE_DELETE_ACTION = []  # project_name
+POST_DELETE_ACTION = []  # project_name
+
+PRE_ACTIVATE_ACTION = []  # project_name
+POST_ACTIVATE_ACTION = []  # project_name
+
+PRE_DEACTIVATE_ACTION = []  # project_name
+POST_DEACTIVATE_ACTION = [
+    create_venv,
+    initialize_git,
+]  # project_name
