@@ -204,7 +204,6 @@ def create_app(project_name, settings_path=None, **settings_patches):
     project_base = project_base_path(project_name)
     project_source = project_source_path(project_name)
     project_logs = project_logs_path(project_name)
-    project_venv = project_venv_path(project_name)
     project_run = project_run_path(project_name)
 
     if os.path.exists(project_base):
@@ -223,26 +222,12 @@ def create_app(project_name, settings_path=None, **settings_patches):
     local('setfacl -m u:apache:rwx %s' % project_logs)
     local('setfacl -m u:apache:rwx %s' % project_run)
 
-    # Initialize venv
-    if not os.path.exists(project_venv):
-        print section_title('Initialize virtual env')
-        with lcd(project_base):
-            local('virtualenv venv')
-
-    # Initialize git
-    if not os.path.exists(os.path.join(project_base, '.git')):
-        print section_title('Make git repository')
-        with lcd(project_base):
-            local('git init')
-            local('touch .gitignore')
-            local('git add .gitignore')
-            local('git commit -m "Init commit"')
-
-    execute(activate_app, project_name, settings_path=settings_path, **settings_patches)
-
     # Post-create actions
     run_hooked_actions('POST_CREATE_ACTIONS')
 
+    # Activate it
+    execute(activate_app, project_name, settings_path=settings_path, **settings_patches)
+
 
 @beanstalk_task(beanstalk_role='server')
 def delete_app(project_name, settings_path=None, **settings_patches):
@@ -260,10 +245,14 @@ def delete_app(project_name, settings_path=None, **settings_patches):
 
     # delete
     if remove:
+        run_hooked_actions('PRE_DELETE_ACTION')
+
         print section_title('Remove app @ %s' % project_base)
         execute(deactivate_app, project_name, settings_path=settings_path, **settings_patches)
         local('rm -rf %s' % project_base)
 
+        run_hooked_actions('POST_DELETE_ACTION')
+
 
 @beanstalk_task(beanstalk_role='server')
 def install_app(project_name, settings_path=None, **settings_patches):
@@ -276,19 +265,8 @@ def install_app(project_name, settings_path=None, **settings_patches):
 
     run_hooked_actions('PRE_INSTALL_ACTIONS')
 
-    project_source = project_source_path(project_name)
-    project_venv = project_venv_path(project_name)
     project_run = project_run_path(project_name)
 
-    print section_title('Install/Update packages in virtualenv')
-    with settings(virtual_env(project_venv)):
-        local('pip install -r %s' % os.path.join(project_source, 'requirements.txt'))
-
-    print section_title('Compile python code')
-    local('find %s -name \'*.pyc\' -exec rm -rf {} \;' % project_source)
-    local('find %s -name \'*.pyo\' -exec rm -rf {} \;' % project_source)
-    local('python -m compileall -q %s' % project_source)
-
     print section_title('Setup uwsgi')
     # edit ini
     uwsgi_path = project_uwsgi_path(project_name)
@@ -381,6 +359,9 @@ def activate_app(project_name, settings_path=None, **settings_patches):
     load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
     project_run = project_run_path(project_name)
+    env.project_name = project_name
+
+    run_hooked_actions('PRE_ACTIVATE_ACTION')
 
     with open(apache_conf_path(), 'r') as f:
         apache_conf = f.read()
@@ -399,16 +380,24 @@ def activate_app(project_name, settings_path=None, **settings_patches):
         local(sed('$ a\\{command}'.format(command=sed_command), apache_conf_path()))
         local('sudo /usr/sbin/httpd_reload')
 
+    run_hooked_actions('POST_ACTIVATE_ACTION')
+
 
 @beanstalk_task(beanstalk_role='server')
 def deactivate_app(project_name, settings_path=None, **settings_patches):
     """Remove app from apache httpd
     """
+    env.project_name = project_name
+
+    run_hooked_actions('PRE_DEACTIVATE_ACTION')
+
     load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
     local(sed('/# {name}/,+7d'.format(name=project_name), apache_conf_path()))
     local('sudo /usr/sbin/httpd_reload')
 
+    run_hooked_actions('POST_DEACTIVATE_ACTION')
+
 
 @beanstalk_task(beanstalk_role='server')
 def build_venv(project_name, settings_path=None, **settings_patches):
@@ -498,6 +487,7 @@ def list_apps(settings_path=None, **settings_patches):
 def add_user(tmp_key_path, clean_tmp_key=False):
     """Add a user's SSH public key to beanstalk
     """
+    # NOTE: Maybe add action hooks
     tmp_key_path = os.path.expanduser(tmp_key_path)
 
     with open(tmp_key_path, 'r') as f:
